/*
 * This file is part of Bugzilla for Java.
 *
 *  Bugzilla for Java is free software: you can redistribute it 
 *  and/or modify it under the terms of version 3 of the GNU 
 *  Lesser General Public  License as published by the Free Software 
 *  Foundation.
 *  
 *  Bugzilla for Java is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public 
 *  License along with Bugzilla for Java.  If not, see 
 *  <http://www.gnu.org/licenses/lgpl-3.0.html>.
 */
package b4j.core.session.jira;

import java.util.Collection;
import java.util.Collections;

import b4j.core.AbstractBugzillaObject;
import b4j.core.Component;
import b4j.core.Project;
import b4j.core.Version;

import com.atlassian.jira.rest.client.domain.BasicProject;

/**
 * Jira implementation of a {@link Project}.
 * @author ralph
 *
 */
public class JiraProject extends AbstractBugzillaObject implements Project {

	private BasicProject project;
	
	/**
	 * Constructor.
	 */
	public JiraProject(BasicProject project) {
		this.project = project;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getName() {
		return project.getName();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getId() {
		return project.getKey();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getDescription() {
		return project.getName();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Collection<Version> getVersions() {
		// TODO 
		return Collections.emptyList();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Collection<Component> getComponents() {
		// TODO
		return Collections.emptyList();
	}

	
}
